loader

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 1, 2020 License: Apache-2.0 Imports: 27 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	RefuncRoot = "/var/run/refunc"
	ConfigFile = "refunc.json"

	DefaultMain        = "/var/runtime/bootstrap"
	AlterMainPath      = "/opt/bootstrap"
	DefaultTaskRoot    = "/var/task"
	DefaultRuntimeRoot = "/var/runtime"
	DefaultLayersRoot  = "/opt"
)

common vars

Functions

This section is empty.

Types

type Loader

type Loader interface {
	Start(ctx context.Context, addr string) error
}

Loader listens to address to load res and handles the bootstrap of a func

func NewSimpleLoader

func NewSimpleLoader(main, taskRoot, runtimeRoot, layersRoot string) Loader

NewSimpleLoader creates a new simple loader, simple loader will listen POST reqeust at /init, and download resouces

Jump to