Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( RefuncRoot = "/var/run/refunc" ConfigFile = "refunc.json" DefaultMain = "/var/runtime/bootstrap" AlterMainPath = "/opt/bootstrap" DefaultTaskRoot = "/var/task" DefaultRuntimeRoot = "/var/runtime" DefaultLayersRoot = "/opt" )
common vars
Functions ¶
This section is empty.
Types ¶
type Loader ¶
Loader listens to address to load res and handles the bootstrap of a func
func NewSimpleLoader ¶
NewSimpleLoader creates a new simple loader, simple loader will listen POST reqeust at /init, and download resouces
Click to show internal directories.
Click to hide internal directories.