Documentation
¶
Index ¶
Constants ¶
const APIVersion = "2018-06-01"
APIVersion for current sidecard
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Engine ¶
type Engine interface {
// Name of current engine
Name() string
// Init engine, that function is loaded
Init(ctx context.Context, fn *types.Function) error
// RegisterServices exports engine's extended services, will mount at <prefix>/<Engine.Name()>
RegisterServices(router *mux.Router)
// ReportInitError runtime encourted a unrecoverable error notify operator to shutdown
ReportInitError(err error)
// ReportReady notify operator that we're ready
ReportReady()
// ReportExiting notify operator that we're exiting
ReportExiting()
// NextC returns a signal channel block and wait for next request
NextC() <-chan struct{}
// InvokeRequest consume a request
InvokeRequest() *messages.InvokeRequest
// SetResult teminates a reqeust corresponding to its reqeust id (rid)
SetResult(rid string, body []byte, err error, conentType string) error
}
Engine is car engine implemented by different transport to commnicate with its operator
type Sidecar ¶
type Sidecar struct {
// contains filtered or unexported fields
}
Sidecar creates a proxy that implements aws lambda runtimes-api https://docs.aws.amazon.com/lambda/latest/dg/runtimes-api.html
Click to show internal directories.
Click to hide internal directories.